==> alwaysai-2.3.4.tgz: package/src/components/docker/find-or-write-dockerfile-component.ts <==
import { writeFileSync, existsSync } from 'fs';
import download = require('download');
import { CliTerseError } from '@alwaysai/alwayscli';

import { confirmWriteFilePromptComponent } from '../general';
import { Spinner, UnableToProceedWithoutMessage } from '../../util';
import { getSystemId } from '../../infrastructure';
import { DOCKER_EDGEIQ_REPOSITORY_NAME } from '../../constants';
import { DOCKERFILE } from '../../paths';

const WRITE_MESSAGE = `Write ${DOCKERFILE}`;
const FOUND_MESSAGE = `Found ${DOCKERFILE}`;
export async function findOrWriteDockerfileComponent(props: { yes: boolean }) {
  const { yes } = props;
  if (existsSync(DOCKERFILE)) {
    Spinner(FOUND_MESSAGE).succeed();
  } else {
    // !exists
    const confirmed =
      yes || (await confirmWriteFilePromptComponent({ fileName: DOCKERFILE }));
    if (!confirmed) {
      throw new CliTerseError(UnableToProceedWithoutMessage(DOCKERFILE));
    }
    const spinner = Spinner(WRITE_MESSAGE);
    let bucket = 'alwaysai-artifacts-prod';
    switch (getSystemId()) {
      case 'development': {
        bucket = 'alwaysai-artifacts-dev';
        break;
      }
      case 'qa': {
        bucket = 'alwaysai-artifacts-qa';
        break;
      }
      case 'production':
      case 'local':
      default:
        bucket = 'alwaysai-artifacts-prod';
    }
    const buffer = await download(
      `https://${bucket}.s3.us-west-1.amazonaws.com/edgeiq/edgeiq.json`,
    );
    const serialized = buffer.toString('utf8');
    const parsed: { version: string; docker: string } = JSON.parse(serialized);
    const version = parsed.docker;
    try {
      writeFileSync(
        DOCKERFILE,
        `ARG ALWAYSAI_HW="default"\nFROM ${DOCKER_EDGEIQ_REPOSITORY_NAME}:$\{ALWAYSAI_HW\}-${version}\n`,
        {
          flag: 'wx',
        },
      );
      spinner.succeed();
    } catch (exception) {
      if (exception.code === 'EEXIST') {
        // Unlikely scenario that the file did not exist but now does
        spinner.succeed(FOUND_MESSAGE);
      } else {
        spinner.fail();
        throw exception;
      }
    }
  }
}

==> alwaysai-2.5.1.tgz: package/src/components/docker/find-or-write-dockerfile-component.ts <==
import { writeFileSync, existsSync } from 'fs';
import download = require('download');
import { CliTerseError } from '@alwaysai/alwayscli';

import { confirmWriteFilePromptComponent } from '../general';
import { Spinner, UnableToProceedWithoutMessage } from '../../util';
import { getSystemId } from '../../infrastructure';
import { DOCKER_EDGEIQ_REPOSITORY_NAME } from '../../constants';
import { DOCKERFILE } from '../../paths';

const WRITE_MESSAGE = `Write ${DOCKERFILE}`;
const FOUND_MESSAGE = `Found ${DOCKERFILE}`;
export async function findOrWriteDockerfileComponent(props: { yes: boolean }) {
  const { yes } = props;
  if (existsSync(DOCKERFILE)) {
    Spinner(FOUND_MESSAGE).succeed();
  } else {
    // !exists
    const confirmed =
      yes || (await confirmWriteFilePromptComponent({ fileName: DOCKERFILE }));
    if (!confirmed) {
      throw new CliTerseError(UnableToProceedWithoutMessage(DOCKERFILE));
    }
    const spinner = Spinner(WRITE_MESSAGE);
    let bucket = 'alwaysai-artifacts-prod';
    switch (getSystemId()) {
      case 'development': {
        bucket = 'alwaysai-artifacts-dev';
        break;
      }
      case 'qa': {
        bucket = 'alwaysai-artifacts-qa';
        break;
      }
      case 'production':
      case 'local':
      default:
        bucket = 'alwaysai-artifacts-prod';
    }
    const buffer = await download(
      `https://${bucket}.s3.us-west-1.amazonaws.com/edgeiq/edgeiq.json`
    );
    const serialized = buffer.toString('utf8');
    const parsed: { version: string; docker: string } = JSON.parse(serialized);
    const version = parsed.docker;
    try {
      writeFileSync(
        DOCKERFILE,
        `ARG ALWAYSAI_HW="default"\nFROM ${DOCKER_EDGEIQ_REPOSITORY_NAME}:$\{ALWAYSAI_HW}-${version}\n`,
        {
          flag: 'wx'
        }
      );
      spinner.succeed();
    } catch (exception) {
      if (exception.code === 'EEXIST') {
        // Unlikely scenario that the file did not exist but now does
        spinner.succeed(FOUND_MESSAGE);
      } else {
        spinner.fail();
        throw exception;
      }
    }
  }
}
